==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у програмі для керування файлами</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Спорожнити журнал</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Освіжити</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Ви певні, що хочете спорожнити журнал?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дні</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 тиждень</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 місяць</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 місяці</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Експортувати</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Експортувати</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Критичне становище</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критична</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Зауваження</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Діагностика</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вхід</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимикання</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Надкритична</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трасування</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>текст (*.txt);; doc (*.doc);; xls (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Експортуємо…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Успішно експортовано</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Не вдалося експортувати</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Експортування до файла</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Період:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Рівень: </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Список програм:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Стан:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Тип події:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Користувач: </translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Дія:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Запис завантаження</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Запис вимикання</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Запис входу</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Діагностика</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Критичне становище</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критична помилка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Зауваження</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трасування</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Надкритична</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Файл журналу є порожнім</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Перегляд журналів</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Переглядач журналу — корисний інструмент для перегляду журналів системи.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Рівень</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процес</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Дата і час</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Джерело</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Тип події</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Рівень:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процес:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Дата і час:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Інформація:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Порожньо</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Дата і час</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Журнал системи</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Журнал ядра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Журнал завантаження</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Журнал dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Журнал KWin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Журнал Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Журнал програм</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Подія завантаження-вимикання</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Журнал dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у програмі для керування файлами</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Спорожнити журнал</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Освіжити</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Ви певні, що хочете спорожнити журнал?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дні</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 тиждень</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 місяць</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 місяці</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Експортувати</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Експортувати</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Критичне становище</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критична</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Зауваження</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Діагностика</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вхід</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимикання</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Надкритична</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трасування</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>текст (*.txt);; doc (*.doc);; xls (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Експортуємо…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Успішно експортовано</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Не вдалося експортувати</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Експортування до файла</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Період:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Рівень: </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Список програм:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Стан:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Тип події:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Користувач: </translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Дія:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Запис завантаження</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Запис вимикання</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Запис входу</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Діагностика</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Критичне становище</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критична помилка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Зауваження</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трасування</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Надкритична</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Файл журналу є порожнім</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Перегляд журналів</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Переглядач журналу — корисний інструмент для перегляду журналів системи.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Рівень</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процес</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Дата і час</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Джерело</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Тип події</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Рівень:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процес:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Дата і час:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Інформація:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Порожньо</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Дата і час</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Журнал системи</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Журнал ядра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Журнал завантаження</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Журнал dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Журнал KWin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Журнал Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Журнал програм</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Подія завантаження-вимикання</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Журнал dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Інтервал оновлення</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 сек.</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 хв.</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Без оновлення</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Експортувати усе</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Журнал системи</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Оновити зараз</translation>
    </message>
</context>
</TS>
